@@ -25,16 +25,10 @@ class BybitDataStore(DataStoreInterface):
         self.create('stoporder', datastore_class=StopOrder)
         self.create('wallet', datastore_class=Wallet)
 
-    async def initialize(self, aws: List[Awaitable[aiohttp.ClientResponse]]):
+    async def initialize(self, *aws: Awaitable[aiohttp.ClientResponse]) -> None:
         for f in asyncio.as_completed(aws):
             resp = await f
-            if resp.status != 200:
-                logger.warning(f'status code != 200 ({resp.url.scheme}://{resp.url.host}{resp.url.path})')
-                continue
             data = await resp.json()
-            if data['ret_code'] != 0:
-                logger.warning(f'ret_code != 0 ({resp.url.scheme}://{resp.url.host}{resp.url.path}) {data}')
-                continue
             if resp.url.path in (
                 '/v2/private/order',
                 '/private/linear/order/search',
@@ -144,25 +138,14 @@ class BybitDataStore(DataStoreInterface):
 class OrderBook(DataStore):
     _KEYS = ['symbol', 'id', 'side']
 
-    def getbest(self, symbol: str) -> Dict[str, Optional[Item]]:
-        result = {'Sell': {}, 'Buy': {}}
-        for item in self._data.values():
-            if item['symbol'] == symbol:
-                result[item['side']][float(item['price'])] = item
-        return {
-            'Sell': result['Sell'][min(result['Sell'])] if result['Sell'] else None,
-            'Buy': result['Buy'][max(result['Buy'])] if result['Buy'] else None
-        }
-
-    def getsorted(self, symbol: str) -> Dict[str, List[Item]]:
+    def sorted(self, query: Item={}) -> Dict[str, List[Item]]:
         result = {'Sell': [], 'Buy': []}
-        for item in self._data.values():
-            if item['symbol'] == symbol:
+        for item in self:
+            if all(k in item and query[k] == item[k] for k in query):
                 result[item['side']].append(item)
-        return {
-            'Sell': sorted(result['Sell'], key=lambda x: float(x['price'])),
-            'Buy': sorted(result['Buy'], key=lambda x: float(x['price']), reverse=True)
-        }
+        result['Sell'].sort(key=lambda x: x['id'])
+        result['Buy'].sort(key=lambda x: x['id'], reverse=True)
+        return result
 
     def _onmessage(self, type_: str, data: Union[List[Item], Item]) -> None:
         if type_ == 'snapshot':
